@@ -9,9 +9,10 @@ from . import BaseController
 
 STREAM_TYPE_UNKNOWN = "UNKNOWN"
 STREAM_TYPE_BUFFERED = "BUFFERED"
-STREAM_TYPE_LIVE = "LIFE"
+STREAM_TYPE_LIVE = "LIVE"
 
 MEDIA_PLAYER_STATE_PLAYING = "PLAYING"
+MEDIA_PLAYER_STATE_BUFFERING = "BUFFERING"
 MEDIA_PLAYER_STATE_PAUSED = "PAUSED"
 MEDIA_PLAYER_STATE_IDLE = "IDLE"
 MEDIA_PLAYER_STATE_UNKNOWN = "UNKNOWN"
@@ -73,7 +74,8 @@ class MediaStatus(object):
     @property
     def player_is_playing(self):
         """ Return True if player is PLAYING. """
-        return self.player_state == MEDIA_PLAYER_STATE_PLAYING
+        return (self.player_state == MEDIA_PLAYER_STATE_PLAYING or
+                self.player_state == MEDIA_PLAYER_STATE_BUFFERING)
 
     @property
     def player_is_paused(self):
@@ -260,7 +262,7 @@ class MediaController(BaseController):
 
         self.media_session_id = 0
         self.status = MediaStatus()
-
+        self.app_id = APP_MEDIA_RECEIVER
         self._status_listeners = []
 
     def channel_connected(self):
@@ -395,7 +397,8 @@ class MediaController(BaseController):
     def play_media(self, url, content_type, title=None, thumb=None,
                    current_time=0, autoplay=True,
                    stream_type=STREAM_TYPE_BUFFERED,
-                   metadata=None):
+                   metadata=None, subtitles=None, subtitles_lang='en-US',
+                   subtitles_mime='text/vtt', subtitle_id=1):
         """
         Plays media on the Chromecast. Start default media receiver if not
         already started.
@@ -410,6 +413,10 @@ class MediaController(BaseController):
         autoplay: bool - whether the media will automatically play.
         stream_type: str - describes the type of media artifact as one of the
             following: "NONE", "BUFFERED", "LIVE".
+        subtitles: str - url of subtitle file to be shown on chromecast.
+        subtitles_lang: str - language for subtitles.
+        subtitles_mime: str - mimetype of subtitles.
+        subtitle_id: int - id of subtitle to be loaded.
         metadata: dict - media metadata object, one of the following:
             GenericMediaMetadata, MovieMediaMetadata, TvShowMediaMetadata,
             MusicTrackMediaMetadata, PhotoMediaMetadata.
@@ -418,7 +425,7 @@ class MediaController(BaseController):
         https://developers.google.com/cast/docs/reference/messages#MediaData
         """
 
-        self._socket_client.receiver_controller.launch_app(APP_MEDIA_RECEIVER)
+        self._socket_client.receiver_controller.launch_app(self.app_id)
 
         msg = {
             'media': {
@@ -443,7 +450,17 @@ class MediaController(BaseController):
                 msg['media']['metadata']['images'] = []
 
             msg['media']['metadata']['images'].append({'url': thumb})
-
+        if subtitles:
+            sub_msg = [{
+                'trackId': subtitle_id,
+                'trackContentId': subtitles,
+                'language': subtitles_lang,
+                'subtype': 'SUBTITLES',
+                'type': 'TEXT',
+                'trackContentType': subtitles_mime,
+                'name': "{} - {} Subtitle".format(subtitles_lang, subtitle_id)
+                }]
+            msg['media']['tracks'] = sub_msg
         self.send_message(msg, inc_session_id=True)
 
     def tear_down(self):
